function myParadigmSetup
% This function initializes the OTBR Toolbox and sets all basic parameters
% of the SOFTWARE in your setup. This function needs to be stored on each
% experimental computer. All required hardware definitions are stored in
% the global variable SETUP created by this function. Edit this function when
% building a new setup. Description of specific field names and values can
% be found in the function..
%
% Copyright 2007-2018
% CC-GNU GPL by attribution
% Please cite the BioPsychology Toolbox where this function is used.
%       http://sourceforge.net/projects/biopsytoolbox/
%
% See also:  start

% VERSION HISTORY:
% Author:         Tobias Otto, Jonas Rose
% Version:        1.2
% Last Change:    18.07.2019
%
% 05.06.2018, Tobias: first draft
% 06.02.2019, Tobias: type punishment
% 18.07.2019, Tobias: typo in switch position comments

%% Init global struct
global SETUP

%% (1) Switch/Image positions in centimeters
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Specify the position of the left upper corner of the switch with
% reference to the left upper corner of the screen.
% REMEMBER for the TOUCH SCREEN that the first number entered in the
% following vectors corresponds to index 1 in the keyBuffer output. The
% second value to index 2 and so on. But only for touchscreens!
SETUP.screen.X        = [0.001, 5.5, 11, 0.001, 5.5, 11, 0.001, 5.5, 11];
SETUP.screen.Y        = [0.1 0.1 0.1 4.2 4.2 4.2 8.3 8.3 8.3];

%% (2) Width and height of the switches/ images in centimeters
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Specify the width and height of the switches in centimeters
SETUP.screen.width    = [5.5 5.5 5.5 5.5 5.5 5.5 5.5 5.5 5.5];
SETUP.screen.height   = [4.2 4.2 4.2 4.2 4.2 4.2 4.2 4.2 4.2];

%% (3) Background color
% Change to background color from black to any another color using short
% names (pre defined in MATLAB) or a RGB triplet ranged from 0 to 1
%
% [1 1 0] --> yellow
% [1 0 1] --> magenta
% [0 1 1] --> cyan
% [1 0 0] --> red
% [0 1 0] --> green
% [0 0 1] --> blue
% [1 1 1] --> white
% [0 0 0] --> black
%
% or anything between zero and one ...
SETUP.screen.bgColor = [0 0 0];

%% (4) Transparency
% Set this value to 1, if you want to enable transparency for your stimuli.
% This is a global setting and transparency has to be enabled for each
% stimulus individually during call of showStimuli
SETUP.screen.transparency = 1;

%% (5) Sound support
% %%%%%%%%%%%%%%%%%%%
% Set this value to one to enable sound support. This should always be the
% case, because some functions use sound options. If this is disabled the
% keyBuffer will not work with the optional argument 'sound' and an error
% occurs.
SETUP.sound.enable = 0;

%% (6) Image to be used as negative feedback
% If specified the given image will be shown during punishment!
% Specify the path to the image as string or leave empty otherwise!
% Image position is full screen by default: [0 0 1 1]
SETUP.punishment.img 	= [];
SETUP.punishment.imgPos	= [0 0 1 1]; %[left, bottom, width, height] figure coordinate
