function enableAutomaticEvents
% This function enables an option that is only available in the network IO
% Boxes and it is usefull for ephys setups only!
% After calling this function the network IO box will automatically send
% triggers to the CED 1401 after receiving input signals or setting
% outputs.
%
% The event codes are the following:
% Input channel 1: 254
% Input channel 2: 253
% Input channel 3: 252
% Input channel 4: 251
% Output channel 1: 250
% Output channel 2: 249
% Output channel 3: 248
% Output channel 4: 247
% Output channel 5: 246

% Tobias Otto
% 1.0
% 07.12.2016

%% Init variables
global SETUP

%% Check for the correct device
if(~strcmpi(SETUP.io.interface, 'NetworkBox'))
    error('This function only works with the network io box! I give up.');
end

% Check for correct network box version!
tmp = bIO;
if(tmp(2) < 3)
    error('Please update the firmware of your network IO Box to use this feature. I give up.');
end

%% Send data to start automatic events
pnet(SETUP.networkDIO.obj, 'write', uint32(98), 'intel');
pnet(SETUP.networkDIO.obj, 'writepacket');

%% User info
disp(' ********************************');
disp(' * Automatic triggers enabled ! *');
disp(' ********************************');


