function out = getKeyBufferResult(hostHandle, varName)
% Use this function to get the results of a keyBuffer call on a remote
% system.
% This function expetcs the variable name of the keyBuffer reults as
% argument. The variables have to exist on the remote computer!
%
% Example: getKeyBufferResult(handle, 'result');


% Tobias Otto
% 1.4
% 26.04.2018

% 04.12.2017, Tobias: first draft
% 03.03.2018, Tobias: ip addresses and handles now in SETUP struct
% 05.03.2018, Tobias: use of sendCommand2Host has changed, adapted code
% 21.03.2018, Tobias: bugfix for more than one good/bad key
% 26.04.2018, Tobias: added definedGood/Bad/neutral keys

%% Init variables
global SETUP
go  = [];
con = SETUP.raspberry.host(hostHandle).con;

%% Call function on remote host to send data
% Use send Command2Host with the optional input that stops the feedback
sendCommand2Host(hostHandle, ['sendKeyBufferResult(' varName ');']);

% Wait for remote host to answer
while(isempty(go))
    go = pnet(con, 'read', 1, 'double');
end

%% Get data for both types of keybuffer and touchbuffer
% Protokoll is:
% - 1: send type
% - 2: size of data for good key followd by good key data
% - 3: size of data for bad key followd by bad key data
% - 4: size of data for neutral key followed by neutral key data
% - 5: Reaction time
% - 6: size of data for defined good key followd by good key data
% - 7: size of data for defined bad key followd by bad key data
% - 8: size of data for defined neutral key followed by neutral key data
% - 9: size of data for raw key followed by raw data

% Type of data
type        = pnet(con, 'read', 1, 'double');
% Good key
siz         = pnet(con, 'read', 1, 'double');
goodKey     = pnet(con, 'read', siz, 'double');
% Bad key
siz         = pnet(con, 'read', 1, 'double');
badKey      = pnet(con, 'read', siz, 'double');
% Neutral key
siz         = pnet(con, 'read', 1, 'double');
neutralKey  = pnet(con, 'read', siz, 'double');
% Reaction time
rt          = pnet(con, 'read', 1, 'double');

% Good key
siz             = pnet(con, 'read', 1, 'double');
defGoodKey      = pnet(con, 'read', siz, 'double');
% Bad key
siz             = pnet(con, 'read', 1, 'double');
defBadKey     	= pnet(con, 'read', siz, 'double');
% Neutral key
siz             = pnet(con, 'read', 1, 'double');
defNeutralKey	= pnet(con, 'read', siz, 'double');

% Raw data
siz             = pnet(con, 'read', 1, 'double');
datDyn          = pnet(con, 'read', 2*siz, 'double');

%% Create keyBuffer struct
out.raw                 = reshape(datDyn, [siz 2]);
out.goodKey             = goodKey;
out.badKey              = badKey;
out.neutralKey          = neutralKey;
out.rt                  = rt;
out.definedGoodKey      = defGoodKey;
out.definedBadKey       = defBadKey;
out.definedNeutralKey   = defNeutralKey;

%% Add data for touchBuffer
if(type == 21)
    % Get data: first global and then local data
    datGlobal   = pnet(con, 'read', 3*siz, 'double');
    datLocal    = pnet(con, 'read', 3*siz, 'double');
    
    % Copy to keyBuffer struct
    out.globalValue = reshape(datGlobal, [siz 3]);
    out.localValue  = reshape(datLocal, [siz 3]);
end
