function [] = connect2ClientPanel(rmtIp, lclIp)

% function [] = connect2ClientPanel(rmtIp, lclIp)
% 
% Use this function to establish a connection to a computer that runs the
% client panel software. This connection enables you the possibility to
% send information  via network to the client panel and allowes a detailed
% monitoring of the paradigm.
%
% Details: This function opens a pnet udp connection on a paradigm-PC (or
% forwarding monitor). The function opens a udp connection with local port
% 5500 on paradigm-PC and generates the remote port using the local
% IP-address (5500 + last three digits of local IP). This logic allows the 
% monitoring PC to open a unique port for each paradigm-PC 
%
% Usage: connect2ClientPanel(rmtIp, lclIp)
%
% Example: connect2ClientPanel('192.168.0.10', '192.168.0.11')

% Author    : Jonas Rose/ Tobias Otto
% Version   : 0.2
% Date      : 14.02.2019

% 17.01.2019, Jonas: first draft
% 14.02.2019, Tobias: added documentation

global SETUP

SETUP.clientPanel.localIP   = lclIp;
SETUP.clientPanel.remoteIP  = rmtIp;
% clients are always port 5500 
SETUP.clientPanel.localPort = 5500;

%% open udp socket
% port on remote monitor depends on local client ip
ind     = strfind(SETUP.clientPanel.localIP,'.');
SETUP.clientPanel.remotePort = ...
    str2double(SETUP.clientPanel.localIP(ind(end)+1:end))+ ...
    SETUP.clientPanel.localPort;
% make the socket
SETUP.clientPanel.lanHand = pnet('udpsocket',SETUP.clientPanel.localPort);
% connect
pnet(SETUP.clientPanel.lanHand,'udpconnect', SETUP.clientPanel.remoteIP, ...
    SETUP.clientPanel.remotePort);
% configure socket to only wait briefly for packets (read)
pnet(SETUP.clientPanel.lanHand,'setreadtimeout',.1);