function [] = send2ClientPanel(varargin)

% function [] = send2ClientPanel(varargin)
%
% Use this function to send information from an experimental setup to a
% network computer. Remote computer uses a clientPanel object to monitor
% the incoming data. Refer to clientPanel documentation for a description
% of the data that can be handled by the clientPanel.
%
% INPUTS
%   varagin : Parameter-vlaue pairs of data for clientPanel
%           : See clientPanel documentation of accepted pairs.
%
% EXAMPLES
%
% send2ClientPanel('trlnr',4,'duration',15,'trlcorr',[1 0 1 1 0 0 0]);
%
% send2ClientPanel('showStimuli', imName, position);
%
% send2ClientPanel('infotext1', 'This is an example text at position 1');

% Author    : Jonas Rose/ Tobias Otto
% Version   : 0.7
% Date      : 25.04.2019

% 25.01.2019, Jonas: first draft
% 06.02.2019, Tobias: added examples to docu
% 14.02.2019, Tobias: replaced : with � to avoid problems with filenames
% 23.02.2019, Jonas : replaced � with '$' (compatibility-issues)
% 23.02.2019, Jonas : replaced '$' with '~' (regexp doesn't split)
% 25.02.2019, Tobias: added check for special characters in user text and replced with ''
% 27.02.2019, Tobias: bugfix: removed commends from necessary code and
%                     bugfix in trlcorr/trlincorr
% 25.04.2019, John: bugfix in converting doubles vector (value not saved)

global SETUP

i=1;
while  i<length(varargin)
    %@ separates the different types of info within package
    pnet(SETUP.clientPanel.lanHand,'write','@');
    % info is sent as parameter~value pair
    pnet(SETUP.clientPanel.lanHand,'write',[varargin{i} '~']);
    
    if strcmpi(varargin{i},'showstimuli')
        % show stimuli on remote machine
        % pick up the file-names from all images
        for j=1:length(varargin{i+1})
            pnet(SETUP.clientPanel.lanHand,'write',[varargin{i+1}(j).filename ';']);
        end
        % send the screen-locations ('pecking-keys')
        pnet(SETUP.clientPanel.lanHand,'write',['~' num2str(varargin{i+2})]);
        % picked up one more argument than in the other cases
        i=1+1;
    elseif islogical(varargin{i+1}) || strcmpi(varargin{i},'trlcorr') || ...
            strcmpi(varargin{i},'trlnorsp') || strcmpi(varargin{i},'trlincorr')
        % force row-vector
        len     = length(varargin{i+1});
        sze     = size(varargin{i+1});
        lVec    = varargin{i+1};
        if sze(1)>sze(2)
            lVec = lVec';
        end
        
        % convert to vector of doubles (treating logical as binary representation)
        % --> first convert bin/double to char (not possible in one way)
        lVec = double(lVec);    % for logicals
        lVec = char(lVec+48);
        
        % --> cut vector into pieces of length 52
        if len>=52 && mod(len,52)~=0
            dubVec = [bin2dec(reshape(lVec(1:floor(len/52)*52), 52, [])');...
                bin2dec(lVec((floor(length(lVec)/52)*52)+1:end))];
        elseif  len>=52
            dubVec = bin2dec(reshape(lVec(1:floor(len/52)*52), 52, [])');
        else
            dubVec = bin2dec(lVec);
        end
        
        % first entry is the length of the original logical vector
        pnet(SETUP.clientPanel.lanHand,'write',num2str(len));
        
        % follow by the actual values
        for j=1:length(dubVec)
            % all values are preceeded by '~'
            pnet(SETUP.clientPanel.lanHand,'write', '~');
            % followe by the actual values
            pnet(SETUP.clientPanel.lanHand,'write',num2str(dubVec(j)));
        end
    elseif isnumeric(varargin{i+1})
        % all numeric data is fine
        pnet(SETUP.clientPanel.lanHand,'write',num2str(varargin{i+1}));
    elseif(ischar(varargin{i+1}))
        % Check char data and remove special characters --> :;@~
        ind = ismember(varargin{i+1}, ':;@~');
        varargin{i+1}(ind) = '';
        % all other character data is fine
        pnet(SETUP.clientPanel.lanHand,'write',varargin{i+1});
    end
    i=i+2;
end
pnet(SETUP.clientPanel.lanHand,'write', char(10));
pnet(SETUP.clientPanel.lanHand,'writepacket');