function fixationCross(varargin)
% Draws a white fixations cross on the screen and waits specified time.
% Two different types of fixations crosses are possible. Use optional
% argument type to change iz.
%
% varargin  -> time     -> time to wait in seconds
%           -> size     -> size of corss in pixel (default 20)
%           -> penWidth -> pen width for cross
%           -> type     -> 1: cross (default) or  2: circle
%           -> color    -> color triplet (default white [255 255 255])
%           -> dontFlip -> don't flip buffers (advanced users)
%
% Example: fixationCross(2);                        % Presents the fixation cross for 2 second
% Example: fixationCross(1.5, 'color', [255 0 0]);  % Presents the fixation cross in red for 1.5 seconds

% Tobias Otto
% 1.6
% 24.03.2020

% 15.10.2007, Tobias: release version
% 15.07.2008, Tobias: Added Example to help
% 05.05.2009, Tobias: Added dontFlip and dontWait to varargin; cosmetics
% 25.01.2015, Tobias: initialized time with zero, removed dontWait!
% 05.02.2018, Tobias: removed WaitSecs and realized time to wait in loop (for timers)
% 17.10.2019, Tobias: added argument structure (first argument can be time without keyword)
% 24.03.2020, tobias: added new type of fixation cross

%% Get access to the WINDOW struct
global WINDOW
global SETUP
time        = 0;
len         = 20;
penWidth    = 2;
color       = [255 255 255];
dontFlip    = 0;
i           = 1;
type        = 1;

%% Parse input arguments
leng = length(varargin);
if(isnumeric(varargin{1}))
    if(leng == 1)
        i       = Inf;
        time    = varargin{1};
    else
        i = i+1;
    end
end

% Continue with optional arguments
while(i <= leng)
    switch lower(varargin{i})
        case 'time'
            i=i+1;
            time = varargin{i};
            i=i+1;
        case 'size'
            i=i+1;
            len = varargin{i};
            i=i+1;
        case 'penwidth'
            i=i+1;
            penWidth = varargin{i};
            i=i+1;
        case 'color'
            i=i+1;
            color = varargin{i};
            i=i+1;
        case 'type'
            i=i+1;
            type = varargin{i};
            i=i+1;
        case 'dontflip'
            dontFlip = 1;
            i = i+1;
        otherwise
            warning(['Ignoring value for ' varargin{i}]);
            i = i+2;
    end
end

%% Compute center and cross coordinates
center = round([WINDOW.rect(3) WINDOW.rect(4)]/2);

%% Draw cross on center
if(type == 1)
    % Screen('DrawLine', windowPtr [,color], fromH, fromV, toH, toV [,penWidth]);
    Screen('DrawLine', WINDOW.handle, color, ...
        center(1)-len, center(2), center(1)+len, center(2), penWidth);
    Screen('DrawLine', WINDOW.handle, color, ...
        center(1), center(2)-len, center(1), center(2)+len, penWidth);
    
elseif(type == 2)
    %% Draw cross-circle on center
    % Draw outer circle
    Screen('FillOval', WINDOW.handle ,color, ...
        [center(1)-len, center(2)-len, center(1)+len, center(2)+len]);
    % Draw cross
    penWidth    = round(len/3);
    penHalf     = round(penWidth/2);
    Screen('DrawLine', WINDOW.handle, SETUP.screen.bgColor, ...
        center(1)-len, center(2), center(1)+len, center(2), penWidth);
    Screen('DrawLine', WINDOW.handle, SETUP.screen.bgColor, ...
        center(1), center(2)-len, center(1), center(2)+len, penWidth);
    % Draw dot
    len = round(penWidth/2.5);
    Screen('FillOval', WINDOW.handle ,color, ...
        [center(1)-len-1, center(2)-len-1, center(1)+len, center(2)+len]);
end
%% Flip finally
if(dontFlip == 0)
    Screen('Flip', WINDOW.handle);
end

%% Wait, if specified
if(time > 0)
    stopTime = GetSecs + time;
    while(GetSecs < stopTime), end
end
