function closeSound
% Use this function to close all audio ports that were initialized using
% initSound
%
% EXAMPLES
% 1.
%   closeSound
%   ans = []
%
% Copyright 2007-2013
% CC-GNU GPL by attribution
% Please cite the BioPsychology Toolbox where this function is used.
%       http://sourceforge.net/projects/biopsytoolbox/
%
% See also:  loadSound, controlSound

% VERSION HISTORY:
% Author:         Tobias Otto
% Version:        1.3
% Last Change:    11.06.2018
%
% 25.07.2013, Tobias: first draft
% 26.09.2013, Tobias: adjusted function for use with psychwrapper
% 09.01.2017, Tobias: using global struct for device handle
% 11.06.2018, Tobias: emergency close for all audio devices

%% Init variables
global SETUP

%% Try to close what we have
count = PsychPortAudio('GetOpenDeviceCount');
if(count ~= 0)
    % Try to stop this audio handle
    try
        PsychPortAudio('Stop', SETUP.sound.handle);
        disp(['--> Stopped audio port "' SETUP.sound.device.DeviceName '"']);
    end
    
    % Try to close audio handle
    try
        PsychPortAudio('Close', SETUP.sound.handle);
        disp(['--> Closed audio port "' SETUP.sound.device.DeviceName '" from global struct']);
    catch
        PsychPortAudio('Close');
        disp('--> Closing all open audio ports!');
    end
    
    % Delete entries in global struct
    SETUP.sound.device = [];
    SETUP.sound.handle = [];
else
    disp('--> No open audio ports found!');
end
