function listSound
% This function lists all available sound systems in the command window.
% The function has no input or output arguments
%
% EXAMPLES
% 1.
%   listSound;    % Automatically get the best results
%
% Copyright 2007-2018
% CC-GNU GPL by attribution
% Please cite the BioPsychology Toolbox where this function is used.
%       http://sourceforge.net/projects/biopsytoolbox/
%
% See also:  initSound, controlSound, closeSound

% VERSION HISTORY:
% Author:         Tobias Otto, Jonas Rose
% Version:        1.2
% Last Change:    13.06.2018

% 29.07.2013, Tobias: first draft
% 26.09.2013, Tobias: adjusted file to work with the psychwrapper
% 13.06.2018, Tobias; added Raspberry support


%% Init variables
global SETUP

%% Get a list of all devices
dev = PsychPortAudio('GetDevices');

%% Display the choices from good to bad
% --> ASIO, WASAPI (on Windows-Vista), WDMKS (on Windows-2000/XP), DirectSound, MME
% --> i=[3 13 11 1 2]
disp('================================================================================');
disp(' This is a list of ASIO sound systems on this computer (known for low latency):');
for i=1:length(dev)
    if(dev(i).HostAudioAPIId == 3 && dev(i).NrOutputChannels ~= 0)
        disp([' Device index: ' num2str(dev(i).DeviceIndex) ' --> Device name ' dev(i).DeviceName]);
    end
end

disp('================================================================================');
disp(' This is a list of WASAPI (on Windows-Vista) sound systems on this computer:');
for i=1:length(dev)
    if(dev(i).HostAudioAPIId == 13 && dev(i).NrOutputChannels ~= 0)
        disp([' Device index: ' num2str(dev(i).DeviceIndex) ' --> Device name ' dev(i).DeviceName]);
    end
end

disp('================================================================================');
disp(' This is a list of  WDMKS (on Windows-2000/XP) sound systems on this computer:');
for i=1:length(dev)
    if(dev(i).HostAudioAPIId == 11 && dev(i).NrOutputChannels ~= 0)
        disp([' Device index: ' num2str(dev(i).DeviceIndex) ' --> Device name ' dev(i).DeviceName]);
    end
end

disp('================================================================================');
disp(' This is a list of  DirectSound sound systems on this computer:');
for i=1:length(dev)
    if(dev(i).HostAudioAPIId == 1 && dev(i).NrOutputChannels ~= 0)
        disp([' Device index: ' num2str(dev(i).DeviceIndex) ' --> Device name ' dev(i).DeviceName]);
    end
end

disp('================================================================================');
disp(' This is a list of MME sound systems on this computer (high latencies):');
for i=1:length(dev)
    if(dev(i).HostAudioAPIId == 2 && dev(i).NrOutputChannels ~= 0)
        disp([' Device index: ' num2str(dev(i).DeviceIndex) ' --> Device name ' dev(i).DeviceName]);
    end
end

disp('================================================================================');
disp(' This is a list of sound systems on a Raspberry Pi:');
for i=1:length(dev)
    if(dev(i).HostAudioAPIId == 8 && dev(i).NrOutputChannels ~= 0)
        disp([' Device index: ' num2str(dev(i).DeviceIndex) ' --> Device name ' dev(i).DeviceName]);
    end
end