function out = startQuestionnaire(text, ansText, varargin)
% This is the main function for questionnaires
% It needs at least two arguments:
%   * text      : a cell that contains all questions
%   * ansText   : a cell that contains the possible answers
%
% In addition startQuestionnaire allows you to modify several *optional*
% parameters:
%   * mainDiv   : A value in percent that devides the screen vertically
%                 into "question part" and answer part"
%   * fontQuest	: Font size for the presented questions
%   * fontAns   : Font size for the possible answers (presented on top of the chart)
%   * startX    : Start position in percent of the chart on the screen.
%   * stopX     : Stop position in percent of the chart on the screen.
%   * penMain   : Pen width in pixel for main question
%   * penUL     : Pen width in pixel for upper and lower question
%   * color     : Color triplet that defines the color for the main  question
%   * colorUL   : Color triplet that defines the color for the upper and lower  question
%   * topText   : A text that is presented on top of the questions. If the
%                 first part of the sentence is always the same.
%   * rowHeight : By default the height of each row is big enough to fit
%                 the text. by using this opotional argument the heigth of
%                 each row will be defined in pixel.

% Tobias Otto
% 1.3
% 09.09.2020

% 08.03.2017, Tobias: first draft
% 09.03.2017, Tobias: minor changes (speed improvement)
% 13.02.2017, Tobias: added optional input topText
% 09.09.2020, Tobias: addded otherwise to switch case

%% Init variables
global WINDOW
global LASTCLICKINQUESTIONNAIRE
LASTCLICKINQUESTIONNAIRE = -1;

trial.mainDivision 	= 0.5;      % Division in persent (text vs. answer fields)
trial.numAnswers    = length(ansText);        % Number of options to answer
trial.fontQuest     = 22;       % Define font size for questions
trial.fontAnsOpt    = 20;       % Define font size for answer options
trial.startX        = 5;        % Table start at x percent of screen (zero is left)
trial.stopX         = 95;       % Table stops at x percent of screen (zero is left)
trial.startY        = 50;       % Height of main question in percent (zero is top)
trial.penMain       = 2;        % Pen width of main question box
trial.penUL         = 1;        % Pen width for upper and lower box
trial.color         = [255 255 255];
trial.colorUL       = round(trial.color*0.35);
trial.topText       = ' ';
trial.rowHeight     = 0;        % Heigth of each text row in pixel (optional)

%% Parse input
i=1;
while(i<=length(varargin))
    switch lower(varargin{i})
        case 'maindiv'
            i                   = i+1;
            trial.mainDivision  = varargin{i}/100;
            i                   = i+1;
        case 'fontquest'
            i                   = i+1;
            trial.fontQuest     = varargin{i};
            i                   = i+1;
        case 'fontans'
            i                   = i+1;
            trial.fontAnsOpt  	= varargin{i};
            i                   = i+1;
        case 'startx'
            i                   = i+1;
            trial.startX        = varargin{i};
            i                   = i+1;
        case 'stopx'
            i                   = i+1;
            trial.stopX         = varargin{i};
            i                   = i+1;
        case 'penmain'
            i                   = i+1;
            trial.penMain       = varargin{i};
            i                   = i+1;
        case 'penul'
            i                   = i+1;
            trial.penUL         = varargin{i};
            i                   = i+1;
        case 'color'
            i                   = i+1;
            trial.color         = varargin{i};
            i                   = i+1;
        case 'colorul'
            i                   = i+1;
            trial.colorUL   	= varargin{i};
            i                   = i+1;
        case 'toptext'
            i                   = i+1;
            trial.topText   	= varargin{i};
            i                   = i+1;
        case 'rowheight'
            i                   = i+1;
            trial.rowHeight     = varargin{i};
            i                   = i+1;
        otherwise
            warning(['Unknown argument: ' varargin{i}]);
            i = i+1;
    end
end

%% Prepare questoinnaire and precompute positions
% Change text size for scale, conserve the old size
trial.oldTextSize = Screen('TextSize',WINDOW.handle ,trial.fontQuest);

% Show Cursor
ShowCursor;

% Add empty space to as first and last entry
text = [{'.'} text {'.'}];

%% Start
for i=1:length(text)-2
    % Present question
    out(i) = startQuestionnaireTable(trial, text(i:i+2), ansText, trial.topText);
    
    % Copy last click to global entry (to present last answer as well)
    LASTCLICKINQUESTIONNAIRE = out(i).index;
    
    % Wait
    WaitSecs(0.2);
end

% Clean screen
showStimuli;

%% Clean up
% Copy old text site back again
Screen('TextSize',WINDOW.handle ,trial.oldTextSize);

% Hide Cursur
HideCursor;

