% srcipt errorSave()
%
% This function is used to warn the user that something went wrong in a
% program. It should be called from within a catch-statement where it opens
% an error-warning and saves all workspace variables so that no data is
% lost. The workspace is saved to the file ErrorTermination_jjjjmmddhhmm.mat
% in the working directory.
%
% EXAMPLES
% 1.
%   try
%       % this is where your entire paradigm happens
%       error('test error')
%   catch
%       bioErrorSave
%   end
%
% Copyright 2007-2018
% CC-GNU GPL by attribution
% Please cite the BioPsychology Toolbox where this function is used.
%       http://biopsytoolbox.sourceforge.net/
%
% See also:  error

% VERSION HISTORY:
% Author:         Tobias Otto, Jonas Rose
% Version:        1.1
% Last Change:    07.06.2018
%
% 06.06.2018, Tobias: first draft based on bioErrorSave
% 07.06.2018, Tobias: save in Octave needs extra parameter to be compatible with MATLAB

%% BUGS/ TODO
% - no known bugs

%% Get last error
errorMessage = lasterror;

%% Save everything we have in workspace
tmp	= ['ErrorTermination_' datestr(now, 'YYYYmmDDHHMMSS') '.mat'];
if(strfind(lower(computer), 'pcwin'))
    save(tmp);
elseif(strfind(lower(computer), 'arm'))
    save(tmp, '-v7');
end

%% User info
msg = ['There was an error executing this program. Workspace and error details are saved in ' tmp];
msgbox(msg,'Error','error');

%% Help user to identify error
disp(' ------------------------------------------------------------------')
disp(' Please check the following files for errors:');
disp(' This is a detailed output of the saved error message.');
disp(' It lists the involved functions for this error.');
disp(' ');
for i=length(errorMessage.stack):-1:1
    disp(errorMessage.stack(i))
end
disp(' ------------------------------------------------------------------')

%% Let caller function throw out the error message
rethrow(errorMessage)