function [cde] = getCode(funNme)
% function [cde] = getCode(funNme)
%
% Returns the code of the named function (*.m file) as unit8. Hast to be
% casted to char for human reading.
%
% INPUTS
% funNme    : name of the function (*.m file) to read
%
% OUTPUTS
% cde       : the code in uint8, needs to be cast to char for human reading
%
% see also: saveCode.m

% VERSION HISTORY:
% Author:         Jonas Rose
% Version:        0.3
%
% Last Change:
% 03.10.15  : Jonas     : first draft
% 04.06.17  : Tobias    : check extension of source file
% 06.02.19  : Tobias    : replace error with warning and return -1 for failure
%
% BUGS/ TODO

%% append .m if it's missing
if ~strncmp(funNme(end:-1:end-1) ,'m.',2)
    funNme = [funNme '.m'];
end

%% check if file exists
if ~exist(funNme,'file')
    warning([funNme ' is not a *.m file'])
    cde = -1;
else
    %% open and read file
    fHand   = fopen(funNme);
    cde     = fread(fHand, inf, 'char');
    fclose(fHand);
end