function mmap = initMRIChatPart1
% Init MRI related functions
% To record all triggers successfully initMRIChatPart2 has to be called
% after initWindow is called!
%
% Returns handle to memory mapped file !!!
% Usage: mmap = initMRIChatPart1

% Tobias Otto
% 1.2
% 04.11.2020

% 29.05.2019, Tobias: first draft based on MRTChatPart1
% 19.10.2020, Tobias: moved global struct globalAnswer to SETUP; enabled more trigger counter applications
% 04.11.2020, Tobias: more user info in case the triggerCounter is not in the current directory

%% Init variables
global SETUP

SETUP.MRI.saveTrigger	= 0;
SETUP.MRI.ScanBeforeWait = GetSecs;
SETUP.MRI.beforeLoop     = GetSecs;
SETUP.MRI.firstItiTime   = GetSecs;
SETUP.MRI.firstItiMRT    = 0;

%% Check for trigger
button = questdlg('Are triggers sent to the computer?','MRI Dialog');
if(strcmpi(button,'Yes'))
    SETUP.MRI.saveTrigger = 1;
    uiwait(warndlg('Trigers will be recorded !!!'));
elseif(strcmpi(button,'Cancle'))
    error('Cancle ... I give up ;)');
elseif(strcmpi(button,'No'))
    uiwait(warndlg('TEST MODE - No triggers will be recorded'));
end

%% Init memory mapped file

%% Check if file exists
memmapFileName  = [pwd filesep 'doNotDeleteThisFile2.dat'];

if(exist(memmapFileName, 'file') == 0)
    % Open file
    fid = fopen(memmapFileName, 'w');
    % Check if we were successful
    if(fid ~= 3)
        error(['Could not create ' memmapFileName '! I give up!']);
    else
        fwrite(fid, [-1 -1 -1 -1], 'double');
        fclose(fid);
        disp(['No memory mapped file found! Creating ' memmapFileName]);
    end
end

%% Start parchat if it exists in the directory
% Only in trigger mode and if user wants to start it automatically
if(~isempty(SETUP.MRI.triggerCounter) && SETUP.MRI.saveTrigger == 1)
    % Create variables (all files need to be in the current directory)
    inpoutx64Name       = [pwd filesep 'inpoutx64.dll'];
    triggerCounterName  = [pwd filesep SETUP.MRI.triggerCounterName];
    startTriggerCounter = 0;
    
    % Choose device
    if(strcmpi(SETUP.MRI.triggerCounter, 'Parallel') && exist(triggerCounterName, 'file') == 2 && exist(inpoutx64Name, 'file') == 2)
        startTriggerCounter = 1;
    elseif(strcmpi(SETUP.MRI.triggerCounter, 'Network') && exist(triggerCounterName, 'file') == 2)
        startTriggerCounter = 1;
    else
        disp(' =======================================================================================================================');
        disp([' The trigger counter: "' triggerCounterName '"']);
        disp([' can''t be found in the working directory "' pwd '"']);
        disp(' --> Please copy the mentioned file into your working directory and try again!');
        disp(' =======================================================================================================================');
        pause(0.5);
    end
    
    if(startTriggerCounter == 1)
        system([triggerCounterName ' &']);
        % Show user info
        dlg	= warndlg('Waiting for the trigger counter to start .... program continues automatically after 10 seconds!');
        WaitSecs(10);
        try close(dlg); end
    else
        fprintf(['Could not start ' triggerCounterName ' automatically! ']);
    end
end

%% Init file
% We're getting our scanner informations from another applications that
% counts the triggers for us. It has to be located in the same directory
% than the working directory of this experiment.

fprintf('Initializing the memory mapped file ...');
% Create handle to memory mapped file
mmap = memmapfile(memmapFileName, 'Format', 'double', 'Writable', true);

if((all(mmap.Data == -1) && SETUP.MRI.saveTrigger == 1) || ...
        SETUP.MRI.saveTrigger == 0)
    fprintf(' done\n')
    mmap.Data   = [0 0 -1 -1];
else
    disp(' ');
    disp(' =========================================================');
    disp(' Couldn''t initialize the memory mapped file successfully!');
    disp(' Either the TriggerCounter application was not started or ');
    disp(' another error occurred. ;)   Anyway I give up');
    disp(' =========================================================');
    error(' Please solve problem and try again !');
end
