function startExperiment
% This helper function turns off all devices, clears the screen and turns
% on the house light. Turning on the house light requires a proper edited
% myHardwareSetup.m file.
% It's useful to call startExperiment after initialization to start with
% controlled conditions.
%
% EXAMPLES
% 1.
%   startExperiment;
%   % Turns off all devices, clears the screen and turns on house light.
%
% Copyright 2007-2019
% CC-GNU GPL by attribution
% Please cite the BioPsychology Toolbox where this function is used.
%       http://sourceforge.net/projects/biopsytoolbox/
%
% See also:  feeding, punishment

% VERSION HISTORY:
% Author:         Tobias Otto, Jonas Rose
% Version:        1.5
% Last Change:    06.03.2019
%
% 17.04.2008, Tobias: Release version
% 08.05.2008, Tobias: Added support for more than one feeder
% 04.06.2008, jonas : minor docu
% 06.11.2008, Tobias: Checks, if a monitor is used
% 08.02.2010, jonas : typos
% 06.03.2019, Tobias: adjusted code for new toolbox

%% BUGS/ TODO

%% Get access to global struct
global SETUP
global WINDOW

%% Turn off everything
bIO(0,0);

%% Clear screen
if(~isempty(WINDOW.handle))
    showStimuli;
end

%% Turn on house light
bIO(SETUP.io.houseLight,ones(1,length(SETUP.io.houseLight)));

