function stopExperiment
% Use this function to "clean up" after your experiment is done.
% This function closes the stimulus presentation window and takes care of
% all stimulus devices that are used (feeder, etc)!
%
%
% Copyright 2007-2019
% CC-GNU GPL by attribution
% Please cite the BioPsychology Toolbox where this function is used.
%       http://sourceforge.net/projects/biopsytoolbox/
%
% See also:  start, initToolbox, initWindow

% Tobias Otto
% 1.3
% 26.03.2019

% 17.07.2017, Tobias: first draft
% 01.03.2018, Tobias: added timer check and delete all timers!
% 15.03.2018, Tobias: cosmetics
% 26.03.2019, Tobias: renamed function (old name is still valid)

%% Init variables
global SETUP
global WINDOW

%% Close stimulus presentation window
closeWindow;

%% Check devices
% Turn on house light, if defined
if(~isempty(SETUP.io.houseLight))
    bIO(SETUP.io.houseLight, 1);
end

% Turn off feeder power, if defined
if(~isempty(SETUP.io.feederPower))
    bIO(SETUP.io.feederPower,zeros(1,length(SETUP.io.feederPower)));
end

%% Close connection to IO box (if necessary)
if(ismember(SETUP.io.interfaceNum, [7 8 10]))
    % Network IO - Pnet - Odroid
    % Network IO - Instrument control toolbox - Odroid
    % Network IO ACN - Pnet - Odroid
    closeNetworkIO;
end

%% Find timers, stop and delete them (Windows only)
if(SETUP.platformNum == 1)
    % Find timers
    t = timerfind;
    
    % Delete timers
    if(~(isempty(t)))
        stop(t);
        delete(t);
        disp('--> Deleted all timer objects');
    end
end
