function texture = showVideo(vid, varargin)
% Function to play a video with the psych toolbox that was loaded using
% loadVideo. Make sure startVideo was called first !!!
%
% Usage: texture = showVideo(vid, varargin)
%
% INPUTS
%   * vid      	: image object
%
% INPUTS-OPTIONAL
%   * x     	: x Position in percent (0 -> left, 100 -> right)
%   * y      	: y Position in percent (0 -> top, 100 -> bottom)
%   * rect     	: Specifies the position of the stimulus in pixel
%   * dontflip	: Don't flip buffers (advanced users)
%
% Returning value signals when the video ends:
% > 0 video is still running
% <= 0 video ends
%
% See also: startVideo, loadVideo, stopVideo, closeVideo

% Tobias Otto
% 1.0
% 29.03.2012

% 29.03.2012, Tobias: first draft
% 04.04.2012, Tobias: added output argument

%% Get access to the WINDOW struct
global WINDOW
dontFlip    = 0;
x           = 50;
y           = 50;
rect        = [];
userRect    = 0;

%% Parse input arguments
i=1;
while(i<=length(varargin))
    switch lower(varargin{i})
        case 'x'
            i           = i+1;
            x           = varargin{i};
            i           = i+1;
        case 'y'
            i           = i+1;
            y           = varargin{i};
            i           = i+1;
        case 'rect'
            i           = i+1;
            rect        = varargin{i};
            userRect    = 1;
            i           = i+1;
        case 'dontflip'
            i           = i+1;
            dontFlip    = 1;
    end
end


%% Compute pixel for position x and y
if(~ischar(x) && ~userRect)
    % Value is given in percent
    x       = round((WINDOW.rect(3)-WINDOW.rect(1)) * x/100);
    rect    = [x-floor(vid.width/2) 0 x+ceil(vid.width/2) 0];
else
    switch lower(x)
        case 'center'
            x = round((WINDOW.rect(3)-WINDOW.rect(1))/2);
            rect = [x-floor(vid.width/2) 0 x+ceil(vid.width/2) 0];
        case 'left'
            x = WINDOW.boundingBox;
            rect = [x 0 x+vid.width 0];
        case 'right'
            x = WINDOW.rect(3) - vid.width - WINDOW.boundingBox;
            rect = [x 0 x+vid.width 0];
    end
end

if(~ischar(y) && ~userRect)
    % Value is given in percent
    y           = round((WINDOW.rect(4)-WINDOW.rect(2)) * y/100);
    rect([2 4])	= [y-floor(vid.height/2) y+ceil(vid.height/2)];
else
    switch lower(y)
        case 'center'
            y = round((WINDOW.rect(4)-WINDOW.rect(2))/2);
            rect([2 4]) = [y-floor(vid.height/2) y+ceil(vid.height/2)];
        case 'top'
            y = WINDOW.boundingBox;
            rect([2 4]) = [y y+vid.height];
        case 'bottom'
            y = WINDOW.rect(4) - vid.height - WINDOW.boundingBox;
            rect([2 4]) = [y y+vid.height];
    end
end

%% Get frame from Video
% Wait for next movie frame, retrieve texture handle to it
texture = Screen('GetMovieImage', WINDOW.handle, vid.handle);

%% Present image
if(texture >= 0)
    Screen('DrawTexture',WINDOW.handle, texture, [], rect);
    
    %% Flip finally
    if(dontFlip == 0)
        Screen('Flip', WINDOW.handle);
    end
    
    %% Release texture
    Screen('Close', texture);
end
